@@ -46,6 +46,12 @@ class LowBar:
         Initializes a few variables
         """
 
+        if not isinstance(bar_load_fill, str):
+            raise TypeError("bar_load_fill should be type str")
+
+        if not isinstance(bar_blank_fill, str):
+            raise TypeError("bar_blank_fill should be type str")
+
         self.completion: int = 1
         self.bar_load_fill: str = bar_load_fill
         self.bar_blank_fill: str = bar_blank_fill
@@ -95,6 +101,9 @@ class LowBar:
         calls _update_bar()
         """
 
+        if not isinstance(percentage, int):
+            raise TypeError("percentage should be type int")
+
         self.completion = percentage
         self._update_bar()
 
@@ -105,6 +114,9 @@ class LowBar:
         Cannot decrease the completed percentage with this function
         """
 
+        if not isinstance(percentage, int):
+            raise TypeError("percentage should be type int")
+
         distance: int = percentage - self.completion
         for i in range(distance):
             del i
@@ -118,6 +130,9 @@ class LowBar:
         Log text to the console without affecting the bar
         """
 
+        if not isinstance(text, str):
+            raise TypeError("text should be type str")
+
         self._overwrite_bar(f"{text}")
         print()
         self._update_bar()
